import { XPromiseExecutor } from './rawInfo';
import { XPromiseError, XPromiseStateEnum } from './utils';
import { promiseNoReject, XPromiseCancelError } from './x-fn';

/** promise拓展 */
export declare class XPromise<T> implements Promise<T> {
    #private;
    /** promise共享 */
    static useSharing: <T_1>(createPromise: () => Promise<T_1>, { rejectClean, resolveClean }?: import('./x-fn').XPromiseSharingOptions) => {
        getStatus: () => XPromiseStateEnum;
        isHasPromise: () => boolean;
        applyPromise: () => Promise<T_1>;
        clearPromise: () => Promise<unknown>;
        getCurrentPromise: () => Promise<T_1> | undefined;
    };
    /** promise重试 */
    static useRetry: <T_1>(createPromise: (retryCount: number, err?: any) => Promise<T_1>, { maxRetry, maxRunTime, maxErrorMessageListLength, canRetry, delay, }: import('./x-fn').XPromiseRetryOptions) => {
        startRetry: () => Promise<T_1>;
        stopRetry: () => Promise<T_1> | undefined;
        getStatus: () => XPromiseStateEnum;
        isRetrying: () => boolean;
    };
    /** promise轮询 */
    static usePolling: <T_1>(args_0: (retryCount: number, err?: any) => Promise<T_1>, args_1: import('./x-fn').XPromiseRetryOptions) => {
        startPolling: () => Promise<T_1>;
        stopPolling: () => Promise<T_1> | undefined;
        getStatus: () => XPromiseStateEnum;
        isPolling: () => boolean;
    };
    /** promise无错 */
    static noReject: typeof promiseNoReject;
    /** 是否是取消/中止错误 */
    static isCancelError: (error: unknown) => error is XPromiseCancelError;
    /** 是否是超时错误 */
    static isTimeoutError: (error: unknown) => error is XPromiseError;
    readonly [Symbol.toStringTag]: string;
    constructor(executorRaw: XPromiseExecutor<T>);
    then<TResult1 = T, TResult2 = never>(onFulfilled?: (value: T) => TResult1 | PromiseLike<TResult1>, onRejected?: (reason: any) => TResult2 | PromiseLike<TResult2>): XPromise<TResult1 | TResult2>;
    catch<TResult = never>(onRejected?: (reason: any) => TResult | PromiseLike<TResult>): XPromise<T | TResult>;
    finally(onFinally?: () => void): XPromise<T>;
    /** 超时设置 */
    timeout: (time: number) => XPromise<T>;
    /** 中止promise */
    abort: (message?: string) => this;
}
