import { XPromiseError, XPromiseErrorCodeEnum, XPromiseStateEnum } from '../utils';

/** promise 重试错误选项 */
export interface XPromiseRetryErrorOptions {
    /** 重试次数 */
    retryCount: number;
    /** 运行时间 */
    runTime: number;
    /** 错误信息列表 */
    errorMessageList: string[];
    /** 错误码 */
    code: XPromiseErrorCodeEnum.ABORT | XPromiseErrorCodeEnum.RETRY_EXCEED_LIMIT | XPromiseErrorCodeEnum.RETRY_CAN_RETRY_FN_FAILED | XPromiseErrorCodeEnum.RETRY_DELAY_FN_FAILED;
    /** 错误消息 */
    message?: string;
}
/** promise 重试错误 */
export declare class XPromiseRetryError extends XPromiseError {
    /** 创建重试错误 */
    static create(options: XPromiseRetryErrorOptions): XPromiseRetryError;
    /** 重试次数 */
    readonly retryCount: number;
    /** 运行时间 */
    readonly runTime: number;
    /** 错误列表 */
    readonly errorMessageList: string[];
    constructor(options: XPromiseRetryErrorOptions);
}
/** 当前重试信息 */
export interface XPromiseCurrentRetryInfo {
    /** 重试次数 */
    retryCount: number;
    /** 运行时间 */
    runTime: number;
}
/** promise 重试选项 */
export interface XPromiseRetryOptions {
    /** 最大重试次数
     * @default 0 默认不重试，即只执行一次
     */
    maxRetry?: number;
    /**
     * 最大运行时间
     * @default Infinity 默认不限制
     */
    maxRunTime?: number;
    /** 最大错误消息列表长度
     * @default 10
     * @minimum 1
     */
    maxErrorMessageListLength?: number;
    /** 是否还可以重试 */
    canRetry?: (
    /** 当前重试信息 */
    currentRetryInfo: XPromiseCurrentRetryInfo, 
    /** 错误 */
    err?: any) => boolean;
    /** 延迟时间 */
    delay?: ((
    /** 当前重试信息 */
    currentRetryInfo: XPromiseCurrentRetryInfo, 
    /** 错误 */
    err?: any) => number) | number;
}
export declare const usePromiseRetry: <T>(createPromise: (retryCount: number, err?: any) => Promise<T>, { maxRetry, maxRunTime, maxErrorMessageListLength, canRetry, delay, }: XPromiseRetryOptions) => {
    /** 开始重试 */
    startRetry: () => Promise<T>;
    /** 停止重试 */
    stopRetry: () => Promise<T> | undefined;
    /** 获取重试状态 */
    getStatus: () => XPromiseStateEnum;
    /** 判断是在重试中 */
    isRetrying: () => boolean;
};
